Programming Guide
=================

This section of the documentation is for people who want to use the
``cmoncrawl`` library to create their own extraction pipeline in python.
It allows use to take full advatange of the ``cmoncrawl`` library unlike
the command line utility which is limited to a few options.

.. note:
    You probably don't need to read this if you just want to use the utility.
    This is for people who want to create their own extraction pipeline.



.. toctree::
    :maxdepth: 2
    :caption: Contents:

    overview
    practice
